Learn R Programming

EpidigiR (version 0.1.2)

clinical_data: Clinical Trials Data for Epidemiological Analysis

Description

A dataset containing simulated clinical trial data for analyzing treatment outcomes, suitable for power calculations, logistic regression, Random Forest, and SVM.

Usage

clinical_data

Arguments

Format

A data frame with 200 rows and 6 columns:

trial_id

Character, unique identifier for each trial participant.

arm

Character, treatment arm (e.g., Treatment, Control).

outcome

Numeric, binary outcome (0 = no response, 1 = response).

age

Numeric, patient age (years).

health_score

Numeric, baseline health score (0 to 100).

dose

Numeric, treatment dose level (e.g., 0 for control, 1 for low dose, 2 for high dose).

Examples

Run this code
data("clinical_data")
clinical_data$outcome <- as.factor(clinical_data$outcome)
epi_model(clinical_data, formula = outcome ~ age + health_score + dose, type = "logistic")
epi_model(clinical_data, formula = outcome ~ age + health_score + dose, type = "rf")
epi_visualize(clinical_data, x = "arm", y = "outcome", type = "boxplot")

Run the code above in your browser using DataLab